@@ -16,3 +16,7 @@ def get_charset(name: str):
 def get_list(name: str):
   if check_name(name):
     return json.loads(pkgutil.get_data(__name__, os.path.join("list", name) + ".json"))
+
+def get_model(name: str):
+  if check_name(name):
+    return pkgutil.get_data(__name__, os.path.join("model", name) + ".h5")
